@@ -11,7 +11,4 @@ def select_range(table, columns=[], rows=[]):
         for column in columns:
             myrow.append(table[row][column])
         table_select.append(myrow)
-    return table_select
-def view_range(table, columns=[], rows=[], filename='TempMytableFile.csv'):
-    table_view = select_range(table, columns, rows)
-    mycsv.write(filename, table_view, delimiter=',')
\ No newline at end of file
+    return table_select
\ No newline at end of file
